<?php
// UNB Components Merger
// Copyright since 2005 by Yves Goergen
// Website: http://unclassified.de/
// Licence: GNU General Public License (GPL) Version 3
//
// This little script reads all UNB Components source files, strips out comments and obviously
// unnecessary white-space and merges all classes into a single file. This file can be parsed and
// cached by PHP more efficiently and thus leads to improved overall performance of UNBC
// applications.

// Encoding: UTF-8 (without BOM) (auto-detect: °°°°°)

// ---------- Begin of configuration ----------

$inputPath = '../src';
$inputFiles = array(
	'lib/database.class.php',
	'lib/configuration.class.php',
	'lib/environment.class.php',
	'lib/debug.class.php',
	'lib/geoip.class.php',
	'lib/publicsuffix.class.php',
	'lib/tomo.class.php',
	'lib/contenttype.class.php',
	'lib/locale.class.php',
	'lib/locales/*.locale.class.php',
	'lib/global.lib.php',
	'lib/ui.lib.php',
	'lib/viewer.class.php',
	'index.php',
	);
$outputFile = '../index.php';
compress();

// ---------- End of configuration ----------

function compress()
{
	global $inputPath, $inputFiles, $outputFile;

	$lines = array();
	foreach ($inputFiles as $filename)
	{
		if (strpos($filename, '*') !== false)
		{
			foreach (glob($inputPath . '/' . $filename) as $filename)
			{
				$lines = array_merge($lines, file($filename));
			}
		}
		else
		{
			$lines = array_merge($lines, file($inputPath . '/' . $filename));
		}
	}

	// Read licence header from first file
	$licence = array();
	for ($i = 0; !preg_match('_^// .+_', $lines[$i]); $i++)
	{
	}
	for (; preg_match('_^// .+_', $lines[$i]); $i++)
	{
		$licence[] = trim($lines[$i]);
	}

	// Append encoding hint to licence block
	#$licence[] = '// Encoding: UTF-8 (without BOM) (auto-detect: °°°°°)';

	$outlines = array();
	$skip = false;
	for ($i = 0; $i < count($lines); $i++)
	{
		$line = $lines[$i];

		$line = trim($line);
		if (!$skip && preg_match('_^##\s*skip$_', $line))
		{
			$skip = true;
			continue;
		}
		if ($skip && preg_match('_^##\s*endskip$_', $line))
		{
			$skip = false;
			continue;
		}
		if ($skip) continue;

		$line = preg_replace('_(^\s*|   )//( .+)?$_', '', $line);   // PHP comments
		$line = preg_replace('_^\s*#.*$_', '', $line);   // PHP comments
		$line = preg_replace('_^\s*}\s*(//|#)\s*class .+$_', '}', $line);   // PHP comments: class names
		$line = preg_replace('_   -- (.+)[^;]$_', '', $line);   // SQL comments (be careful with the -- operator in PHP code!)
		$line = preg_replace('~^if\s*\(!class_exists\(\'Unb[A-Za-z]+\'(,\s*false)?\)\)\s*require_once\s+__DIR__ . \'/[./a-z]+.class.php\';$~', '', $line);
		$line = trim($line);

		// Merge immediately connected PHP regions (originally from different files now glued together)
		if ($line == '?>' && trim($lines[$i + 1]) == '<?php')
		{
			$i++;
			continue;
		}

		if ($line != '') $outlines[] = $line;
	}

	// Insert licence header in output file
	for ($i = 0; !preg_match('_<?php_i', $outlines[$i]); $i++)
	{
	}
	$i++;
	$outlines1 = array_slice($outlines, 0, $i);
	$outlines2 = array_slice($outlines, $i);
	$outlines = array_merge($outlines1, $licence, $outlines2);

	$fp = fopen($outputFile, 'w');
	fwrite($fp, join("\n", $outlines) . "\n");
	fclose($fp);
}
?>
